\name{coalition}

\alias{coalition}

\title{Coalition Dissolution in Parliamentary Democracies}

\description{
  This data set contains survival data on government coalitions in
  parliamentary democracies (Belgium, Canada, Denmark, Finland, France,
  Iceland, Ireland, Israel, Italy, Netherlands, Norway, Portugal, Spain,
  Sweden, and the United Kingdom) for the period 1945-1987.  For
  parsimony, country indicator variables are omitted in the sample data.  
}

\usage{data(coalition)}

\format{
  A table containing 7 variables ("duration", "ciep12", "invest",
  "fract", "polar", "numst2", "crisis") and 314 observations.  For
  variable descriptions, please refer to King, Alt, Burns and Laver
  (1990).  
}

\source{ICPSR}

\references{
  King, Gary, James E. Alt, Nancy Elizabeth Burns and Michael Laver (1990).
  ``A Unified Model  of Cabinet Dissolution in Parliamentary
  Democracies,'' \emph{American Journal of Political Science}, vol. 34,
  no. 3, pp. 846-870.  
  
  Gary King, James E. Alt, Nancy Burns, and Michael Laver.  ICPSR
  Publication Related Archive, 1115.
}

\keyword{datasets}



\eof
\name{gsource}

\alias{gsource}

\title{Read Data As a Space-Delimited Table}

\description{
  The \code{gsource} function allows you to read a space delimited table
  as a data frame.  Unlike \code{scan}, you may use \code{gsource} in a
  \code{source}ed file, and unlike \code{read.table}, you may use
  \code{gsource} to include a small (or large) data set in a file that
  also contains other commands.
}

\usage{
gsource(var.names = NULL, variables)
}

\arguments{
  \item{var.names}{An optional vector of character strings representing
    the column names.  By default, \code{var.names = NULL}. }
  \item{variables}{A single character string representing the data.  You
    may use \code{\\ } or \code{\\n} to indicate new lines.  }
}

\value{
  The output from \code{gsource} is a data frame, which you may save to
  an object in your workspace.
}

\seealso{\code{read.table}, \code{scan}}

\author{ Olivia Lau <\email{olau@fas.harvard.edu}>
}

\examples{
\dontrun{
data <- gsource(variables =  "\
                 1 2 3 4 5    \
                 6 7 8 9 10   \
                 3 4 5 1 3    \
                 6 7 8 1 9    ")

data <- gsource(var.names = "Vote Age Party", variables = "\
                             0    23 Democrat             \
                             0    27 Democrat             \
			     1    45 Republican           \
                             1    65 Democrat             ")
}
}

\keyword{file}

\eof
\name{help.zelig}

\alias{help.zelig}

\title{HTML Help for Zelig Commands and Models}

\description{
  The \code{help.zelig} command launches html help for Zelig commands
  and supported models.  The full manual is available online at
  \url{http://gking.harvard.edu/zelig}.
  }

\usage{
help.zelig(object)
}

\arguments{
  \item{object}{a character string representing a Zelig command or model. 
    \code{help.zelig("command")} will take you to an index of Zelig
    commands and \code{help.zelig("model")} will take you to a list of
    models. }
  }

\seealso{The complete document is available online at
  \url{http://gking.harvard.edu/zelig}.  
}

\references{Gary King, Michael Tomz, and Jason Wittenberg (2000),
``Making the Most of Statistical Analyses: Improving Interpretation and
  Presentation,'' \emph{American Journal of Political Science}, vol. 44,
  pp.347--355.
}

\author{
  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Olivia Lau<\email{olau@fas.harvard.edu}>
}

\keyword{documentation}









\eof
\name{immigration}

\alias{immigration}
\alias{immi1}
\alias{immi2}
\alias{immi3}
\alias{immi4}
\alias{immi5}
\alias{data}

\title{Individual Preferences Over Immigration Policy}

\description{These five datasets are part of a larger set of 10 multiply
  imputed data sets describing individual preferences toward immigration
  policy.  Imputation was performed via Amelia.  
}

\usage{data(immi1, immi2, immi3, immi4, immi5)}

\arguments{
  \item{data}{Calls the data sets from the sample data directory.}
  \item{immi1}{1st multiply imputed data set.}
  \item{immi2}{2nd multiply imputed data set.}
  \item{immi3}{3rd multiply imputed data set.}
  \item{immi4}{4th multiply imputed data set.}
  \item{immi5}{5th multiply imputed data set.}
}

\format{
  Each multiply-inputed data set consists of a table with 7 variables ("ipip", "wage1992", "prtyid",
  "ideol", "gender") and 2,485 observations.  For variable descriptions,
  please refer to Scheve and
  Slaugher, 2001.  
}

\source{National Election Survey}

\references{
 Scheve, Kenneth and Matthew Slaughter (2001). ``Labor Market Competition
 and Individual Preferences Over Immigration Policy,'' \emph{The Review of
 Economics and Statistics}, vol. 83, no. 1, pp. 133-145.  }

\keyword{datasets}



\eof
\name{macro}

\alias{macro}

\title{Macroeconomic Data}

\description{
  Selected macroeconomic indicators for Austria, Belgium, Canada,
  Denmark, Finland, France, Italy, Japan, the Netherlands, Norway,
  Sweden, the United Kingdom, the United States, and West Germany for
  the period 1966-1990.  
}

\usage{data(macro)}

\format{
  A table containing 6 variables ("country", "year", "gdp", 
  "unem", "capmob", and "trade") and 350 observations.
}

\source{ICPSR}

\references{
  King, Gary, Michael Tomz and Jason Wittenberg. ICPSR Publication
  Related Archive, 1225.
  
  King, Gary, Michael Tomz and Jason Wittenberg (2000).
  ``Making the Most of Statistical Analyses: Improving Interpretation and 
  Presentation,'' \emph{American Journal of Political Science}, vol. 44,
  pp. 341-355.
}

\keyword{datasets}





\eof
\name{match.data}

\alias{match.data}

\title{Output matched data sets}

\description{The code \code{match.data} creates output data sets from the \code{matchit}
matching algorithm.}

\usage{
match.data <- match.data(object, group = "all")
}

\arguments{ 
\item{object}{Stored output from \code{matchit}.} 

\item{group}{Which units to output.  Selecting "all" (default) gives all
matched units (treated and control), "treat" gives just the matched
treated units, and "control" gives just the matched control units.} }

\value{ The \code{match.data} command generates a matched data set from
the output of the \code{matchit} function, according to the options
selected in the \code{group} argument.  The matched data set contains
the additional variables: 
  \item{pscore}{The propensity score for each unit.}
  \item{psclass}{The subclass index for each unit (if applicable).}
  \item{psweights}{The weight for each unit (generated from the matching
    procedure).}
See the \code{matchit} documentation for more details on these items.
}

\seealso{The complete documentation for \code{matchit} is available online at
  \url{http://gking.harvard.edu/matchit}.}

\author{
  Daniel Ho <\email{deho@fas.harvard.edu}>; Kosuke Imai
  <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Elizabeth Stuart<\email{stuart@stat.harvard.edu}>
}

\keyword{methods}

\eof
\name{mexico}

\alias{mexico}

\title{Voting Data from the 1988 Mexican Presidental Election}

\description{
  This dataset contains voting data for the 1988 Mexican presidential
  election.  
}

\usage{data(mexico)}

\format{A table containing 33 variables and 1,359 observations.}

\source{ICPSR}

\references{
  King, Gary, Michael Tomz and Jason Wittenberg (2000).
  ``Making the Most of Statistical Analyses: Improving Interpretation and 
  Presentation,'' \emph{American Journal of Political Science}, vol. 44,
  pp. 341-355.

  King, Tomz and Wittenberg.  ICPSR Publication Related Archive, 1255.  
}

\keyword{datasets}


\eof
\name{mid}

\alias{mid}

\title{Militarized Interstate Disputes}

\description{
  A small sample from the militarized interstate disputes database,
  available at \url{http://pss.la.psu.edu/MID_DATA.HTM}.  
}

\usage{data(mid)}

\format{
  A table containing 6 variables ("conflict", "major", "contig", 
  "power", "maxdem", "mindem", and "years") and 3,126 observations.  For
  full variable descriptions, please see King and Zeng, 2001.  
}

\source{Militarized Interstate Disputes database}

\references{
  King, Gary, and Lanche Zeng (2001).  ``Explaining Rare Events in
  International Relations,'' \emph{International Organization}, vol. 55,
  no. 3, pp. 693-715.  

  Jones, Daniel M., Stuart A. Bremer and David Singer (1996).  ``Militarized
  Interstate Disputes, 1816-1992: Rationale, Coding Rules, and Empirical
  Patterns,'' \emph{Conflict Management and Peace Science}, vol. 15,
  no. 2, pp. 163-213.  
}

\keyword{datasets}



\eof
\name{plot.ci}

\alias{plot.ci}

\title{Plotting Vertical confidence Intervals}

\description{ The \code{plot.ci} command generates vertical
  confidence intervals for linear or generalized linear univariate
  response models.  }

\usage{
plot.ci(object, CI = 95, qi = "ev", main, ylab, xlab, xlim, ylim, 
        col = c("red", "blue"), ...) 
}

\arguments{
  \item{object}{stored output from \code{sim}.  The \code{x} and optional
  \code{x1} values used to generate the \code{sim} output object must
  have more than one observation.}  
\item{CI}{the selected confidence interval.  Defaults to 95
  percent.}
\item{qi}{the selected quantity of interest.  Defaults to
  expected values.}
\item{main}{a title for the plot.}
\item{ylab}{label for the y-axis.}
\item{xlab}{label for the x-axis.}
\item{xlim}{limits on the x-axis.}
\item{ylim}{limits on the y-axis.}
\item{col}{a vector of at most two colors for plotting the
  expected value given by \code{x} and the alternative set of expected
  values given by \code{x1} in \code{sim}.  If the quantity of
  interest selected is not the expected value, or \code{x1 = NULL},
  only the first color will be used.}
\item{\dots}{Additional parameters passed to \code{plot}.}
}  

\value{
For all univariate response models, {\tt plot.ci()} returns vertical
confidence intervals over a specified range of one explanatory
variable.  You may save this plot using the commands described in the
Zelig manual (\url{http://gking.harvard.edu/zelig}).  
}

\example{
data(turnout)
z.out <- zelig(vote ~ race + educate + age + I(age^2) + income,
               model = "logit", data = turnout)
age.range <- 18:95
x.low <- setx(z.out, educate = 12, age = age.range)
x.high <- setx(z.out, educate = 16, age = age.range)
s.out <- sim(z.out, x = x.low, x1 = x.high)
plot.ci(s.out, xlab = "Age in Years",
        ylab = "Predicted Probability of Voting",
        main = "Effect of Education and Age on Voting Behavior")
legend(45, 0.52, legend = c("College Education (16 years)",
       "High School Education (12 years)"), col = c("blue","red"), 
       lty = c("solid"))
}

\seealso{
  The full Zelig manual is available at
  \url{http://gking.harvard.edu/zelig}, and users may also wish to see
  \code{plot}, \code{lines}.
  }

\author{
  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Olivia Lau <\email{olau@fas.harvard.edu}>
}

\keyword{hplot}






\eof
\name{plot.zelig}

\alias{plot.zelig}
\alias{plot}

\title{Graphing Quantities of Interest}

\description{ The \code{zelig} method for the generic \code{plot}
  command generates default plots for \code{\link{sim}} output with
  one-observation values in \code{x} and \code{x1}.  }

\usage{
\method{plot}{zelig}(object, alt.col = "red", xlab = "", user.par = FALSE, ...)
}

\arguments{
\item{object}{stored output from \code{\link{sim}}.  If the \code{x} or
  \code{x1} values stored in the object contain more than one
  observation, \code{plot.zelig} will return an error.  For linear or
  generalized linear models with more than one observation in \code{x}
  and optionally \code{x1}, you may use \code{\link{plot.ci}}.  }
\item{alt.col}{alternative color used for contrast in the plots.  The
    primary color is black, and the alternative color is red by
    defualt.  Type \code{colors()} to see a list of available
    alternative colors.  }
\item{xlab}{a character string for the x-axis label for all graphs.}
\item{user.par}{a logical value indicating whether to use the default
    Zelig plotting parameters (\code{user.par = FALSE}) or
    user-defined parameters (\code{user.par = TRUE}), set using the
    \code{par} function prior to plotting. }
\item{\dots}{Additional parameters passed to \code{plot.default}.
  Because \code{plot.zelig} primarily produces diagnostic plots, many
  of these parameters are hard-coded for convenience and
  presentation. }  
}

\value{
Depending on the class of model selected, \code{plot.zelig} will
return an on-screen window with graphs of the various quantities of
interest.  You may save these plots using the commands described in
the Zelig manual (available at \url{http://gking.harvard.edu/zelig}).  
}

\seealso{ The full Zelig manual at
  \url{http://gking.harvard.edu/zelig} and \code{plot}, \code{lines},
  and \code{par}.  }

\author{
  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Olivia Lau <\email{olau@fas.harvard.edu}>
}

\keyword{hplot}

\eof
\name{repl}

\alias{repl}
\alias{repl.default}
\alias{repl.zelig}

\title{Replicating Analyses}

\description{ The generic function \code{repl} command takes 
\code{\link{zelig}} or
  \code{\link{sim}} output objects and replicates (literally, re-runs)
  the entire analysis.  The results should be an output 
object
  identical to the original input object in the case of
  \code{\link{zelig}} output.  In the case of \code{\link{sim}}
  output, the replicated analyses may differ slightly due to
  stochastic randomness in the simulation procedure.  }

\usage{
repl(object, \dots)
repl.default(object, data = NULL, \dots)
repl.zelig(object, prev = NULL, data = NULL, x = NULL, x1 = NULL,
     bootfn = NULL, \dots) 
}

\arguments{
\item{object}{Stored output from either \code{\link{zelig}} or
    \code{\link{sim}}.}
\item{data}{You may manually input the data frame name rather
  than allowing replicate to draw the data frame name from the object
  to be replicated.}
\item{prev}{When replicating \code{\link{sim}} output, you may
  optionally use the previously simulated parameters to calculate the
  quantities of interest rather than simulating a new set of
  parameters.  For all models, this should produce identical
  quantities of interest.  In addition, for if the parameters were
  bootstrapped in the original analysis, this will save a considerable
  amount of time. }
\item{x}{When replicating \code{\link{sim}} output, you may
  optionally use an alternative \code{\link{setx}} value for the \code{x}
  input. } 
\item{x1}{When replicating \code{\link{sim}} output, you may
  optionally use an alternative \code{\link{setx}} object for the \code{x1}
  input to replicating the \code{\link{sim}} object. }
\item{bootfn}{When replicating \code{\link{sim}} output with
    bootstrapped parameters, you should manually specify the
    \code{bootfn} if a non-default option was used.  }
\item{\dots}{Additional arguments passed to either \code{\link{zelig}} or 
\code{\link{sim}}.  }
}

\value{
For \code{\link{zelig}} output, \code{repl} will create output that is in
every way identical to the original input.  You may check to see
whether they are identical by using the \code{identical} command.  

For \code{\link{sim}} output, \code{repl} output will be will be
identical to the original object if you choose not to simulate new
parameters, and instead choose to calculate quantities of interest
using the previously simulated parameters (using the \code{prev}
option.  If you choose to simulate new parameters, the summary
statistics for each quantity of interest should be identical, up to a
random approximation error.  As the number of simulations increases,
this error decreases.
}

\seealso{ \code{\link{zelig}}, \code{\link{setx}}, and
  \code{\link{sim}}.  In addition, the full Zelig manual may be
  accessed online at \url{http://gking.harvard.edu/zelig}.  }

\example{
data(turnout)
z.out <- zelig(vote ~ race + educate, model = "logit", data = turnout[1:1000,$
x.out <- setx(z.out)
s.out <- sim(z.out, x = x.out)
z.rep <- repl(z.out)
identical(z.out$coef, z.rep$coef)
z.alt <- repl(z.out, data = turnout[1001:2000,])
s.rep <- repl(s.out, prev = s.out$par)
identical(s.out$ev, s.rep$ev)
}


\author{
  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Olivia Lau <\email{olau@fas.harvard.edu}>
}

\keyword{file}

\eof
\name{rocplot}

\alias{rocplot}
\alias{roc}
\alias{ROC}
\alias{ROCplot}

\title{Receiver Operator Characteristic Plots}

\description{
The \code{rocplot} command generates a receiver operator
characteristic plot to compare the in-sample (default) or
out-of-sample fit for two logit or probit regressions.  
}

\usage{
rocplot(y1, y2, fitted1, fitted2, cutoff = seq(from=0, to=1, length=100), 
        lty1 = "solid", lty2 = "dashed", lwd1 = par("lwd"), lwd2 = par("lwd"),
        col1 = par("col"), col2 = par("col"), main, xlab, ylab, ...)
}

\arguments{
\item{y1}{Response variable for the first model.  }
\item{y2}{Response variable for the second model. }
\item{fitted1}{Fitted values for the first model.  These values
  may represent either the in-sample or out-of-sample fitted values. }
\item{fitted2}{Fitted values for the second model. } 
\item{cutoff}{A vector of cut-off values between 0 and 1, at
  which to evaluate the proportion of 0s and 1s correctly predicted by
  the first and second model.  By default, this is 100 increments
  between 0 and 1, inclusive.  }
\item{lty1, lty2}{The line type for the first model ({\tt
    lty1}) and the second model (\code{lty2}), defaulting to solid and
  dashed, respectively.    }
\item{lwd1, lwd2}{The width of the line for the first
  model (\code{lwd1}) and the second model (\code{lwd2}), defaulting to
  1 for both.  }
\item{col1, col2}{The colors of the line for the first
  model (\code{col1}) and the second model (\code{col2}), defaulting to
  black for both. }
\item{main}{a title for the plot.  Defaults to "Roc Curve".}
\item{xlab}{a label for the x-axis.  Defaults to "Proportion of 1's 
Correctly Predicted".}
\item{ylab}{a label for the y-axis.  Defaults to Proportion of 0's 
Correctly Predicted".}
\item{\dots}{Additional parameters passed to plot, including
  \code{xlab}, \code{ylab}, and \code{main}.  }
}

\value{
For two logit or probit models, \code{rocplot} returns an on-screen
window with the desired ROC plot.  
}

\example{
data(turnout)
z.out1 <- zelig(vote ~ race + educate + age, model = "logit", 
                data = turnout)
z.out2 <- zelig(vote ~ race + educate, model = "logit", 
                data = turnout)
rocplot(z.out1$y, z.out2$y, fitted(z.out1), fitted(z.out2))
}

\seealso{ The full Zelig manual (available at
  \url{http://gking.harvard.edu/zelig}), \code{plot}, \code{lines}.  }

\author{
  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Olivia Lau <\email{olau@fas.harvard.edu}>
}

\keyword{aplot}

\eof
\name{sanction}

\alias{sanction}

\title{Multilateral Economic Sanctions}

\description{
  Data on bilateral sanctions behavior for selected years during the
  general period 1939-1983.  This data contains errors that have since
  been corrected.  Please contact Lisa Martin before using this data for
  publication.   
}

\usage{data(sanction)}

\format{A table containing 8 variables ("mil", "coop", "target",
  "import", "export", "cost", "num", and "ncost") and 78 observations.
  For full variable description, see Martin, 1992. }

\source{Martin, 1992}

\references{
  Martin, Lisa (1992).  \emph{Coercive Cooperation: Explaining Multilateral
    Economic Sanctions}, Princeton: Princeton University Press.
}

\keyword{datasets}

\eof
\name{setx}

\alias{setx}

\title{Setting Explanatory Variable Values}

\description{ The \code{setx} command uses the variables identified in
  the \code{formula} generated by \code{zelig} and sets the values of
  the explanatory variables to the selected values.  Use \code{setx}
  after \code{zelig} and before \code{sim} to simulate quantities of
  interest.  }

\usage{
x.out <- setx(object, fn = list(numeric = mean, ordered = median, 
                                others = mode), 
              data = NULL, cond = FALSE, \dots)
}

\arguments{
  \item{object}{the saved output from \code{\link{zelig}}. }
  \item{fn}{a list of functions to apply to three types of variables:
      \item{numeric}{\code{numeric} variables are set to their mean by
      default, but you may select any mathematical function to apply to
      numeric variables.}
      \item{ordered}{\code{ordered} factors are set to their meidan by
      default, and most mathematical operations will work on them.  If
      you select \code{ordered = mean}, however, \code{setx} will
      default to median with a warning.}
      \item{other}{variables may consist of unordered factors, character
	strings, or logical variables.  The \code{other} variables may
	only be set to their mode.  If you wish to set one of the other
	variables to a specific value, you may do so using \code{\dots}
	below. }
    In the special case \code{fn = NULL}, \code{setx} will return all
    of the observations without applying any function to the data.  }
  \item{data}{a new data frame used to set the values of
    explanatory variables. If \code{data = NULL} (the default), the
    data frame called in \code{zelig} is used. }
  \item{cond}{a logical value indicating whether unconditional
    (default) or conditional (choose \code{cond = TRUE}) prediction
    should be performed.  If you choose \code{cond = TRUE}, \code{setx}
    will coerce \code{fn = NULL} and ignore the additional arguments in 
    \code{\dots}.  If \code{cond = TRUE} and \code{data = NULL},
    \code{setx} will prompt you for a data frame.  }  
  \item{\dots}{user-defined values of specific variables
    overwriting the default values set by the function \code{fn}.  For
    example, adding \code{var1 = mean(data\$var1)} or \code{x1 = 12}
    explicitly sets the value of \code{x1} to 12.  In addition, you may
    specify one explanatory variable as a range of values, creating one
    observation for every unique value in the range of values. }
}

\value{
  For unconditional prediction, \code{x.out} is a model matrix based
  on the specified values for the explanatory variables.  For multiple
  analyses (i.e., when choosing the \code{by} option in \code{\link{zelig}},
  \code{setx} returns the selected values calculated over the entire
  data frame.  If you wish to calculate values over just one subset of
  the data frame, the 5th subset for example, you may use:  
\begin{verbatim}
x.out <- setx(z.out[[5]])
\end{verbatim} 

For conditional prediction, \code{x.out} includes the model matrix
  and the dependent variables.  For multiple analyses (when choosing
  the \code{by} option in \code{zelig}), \code{setx} returns the
  observed explanatory variables in each subset.
}

\example{
# Unconditional prediction:
data(turnout)
z.out <- zelig(vote ~ race + educate, model = "logit", data = turnout)
x.out <- setx(z.out)
s.out <- sim(z.out, x = x.out)

# Unconditional prediction with all observations:
x.out <- setx(z.out, fn = NULL)
s.out <- sim(z.out, x = x.out)

# Unconditional prediction with out of sample data:
z.out <- zelig(vote ~ race + educate, model = "logit",
               data = turnout[1:1000,])
x.out <- setx(z.out, data = turnout[1001:2000,])
s.out <- sim(z.out, x = x.out)

# Using a user-defined function in fn:
quants <- function(x)
  quantile(x, 0.25)
x.out <- setx(z.out, fn = list(numeric = quants))

# Conditional prediction:  
data(lalonde)
match.out <- matchit(treat ~ age + educ + black + hispan + married + 
                     nodegree + re74 + re75, data = lalonde)
z.out <- zelig(re78 ~ pscore, data = match.data(match, "control"), 
               model = "ls")
x.out <- setx(z.out, fn = NULL, data = match.data(match.out, "treat"),
	      cond = TRUE)
s.out <- sim(z.out, x = x.out)
}

\seealso{ The full Zelig manual may be accessed online at
  \url{http://gking.harvard.edu/zelig}.  }

\author{
  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Olivia Lau <\email{olau@fas.harvard.edu}>
}

\keyword{file}

\eof
\name{sim}

\alias{sim}

\title{Simulating Quantities of Interest}

\description{ Simulate quantities of interest from the estimated model
  output from \code{zelig()} given specified values of explanatory
  variables established in \code{setx()}.  For classical \emph{maximum
    likelihood} models, \code{sim()} uses asymptotic normal
  approximation to the log-likelihood.  For \emph{Bayesian models},
  Zelig simulates quantities of interest from the posterior density,
  whenever possible.  For \emph{robust Bayesian models}, simulations
  are drawn from the identified class of Bayesian posteriors.
  Alternatively, you may generate quantities of interest using
  bootstrapped parameters.  }

\usage{
s.out <- sim(object, x, x1 = NULL, num = c(1000, 100), prev = NULL, 
             bootstrap = FALSE,  bootfn = NULL, cond.data = NULL, \dots)
}

\arguments{
  \item{object}{the output object from \code{\link{zelig}}. }
  \item{x}{values of explanatory variables used for simulation,
      generated by \code{\link{setx}}.  }
  \item{x1}{optional values of explanatory variables (generated by a
      second call of \code{\link{setx}}), used to simulate first
      differences and risk ratios.  (Not available for conditional
      prediction.) }
  \item{num}{the number of simulations, i.e., posterior draws.  If the
      \code{num} argument is omitted, \code{sim} draws 1,000
      simulations by if \code{bootstrap = FALSE} (the default), or 100
      simulations if \code{bootstrap = TRUE}.  You may increase this
      value to improve accuracy.  (Not available for conditional
      prediction.) }
  \item{bootstrap}{a logical value indicating if parameters
    should be generated by re-fitting the model for bootstrapped
    data, rather than from the likelihood or posterior.  (Not
    available for conditional prediction.) }
  \item{bootfn}{a function which governs how the data is
    sampled, re-fits the model, and returns the bootstrapped model
    parameters.  If \code{bootstrap = TRUE} and \code{bootfn = NULL},
    \code{\link{sim}} will sample observations from the original data
    (with
    replacement) until it creates a sampled dataset with the same
    number of observations as the original data.  Alternative
    bootstrap methods include sampling the residuals rather than the
    observations, weighted sampling, and parametric bootstrapping.
    (Not available for conditional prediction.) }  
  \item{cond.data}{a data frame, identical to the \code{data}
    argument in \code{\link{setx}}.  Required for conditional prediction
    with the exponential, Weibull, and lognormal models. } 
  \item{\dots}{additional optional arguments passed to
    \code{boot}. }
}

\value{ The output stored in \code{s.out} varies by model.  Use the
  \code{names} command to view the output stored in \code{s.out}.
  Common elements include:  {
  \item{x}{the \code{\link{setx}} values for the explanatory variables,
    used to calculate the quantities of interest (expected values,
    predicted values, etc.). }
  \item{x1}{the optional \code{\link{setx}} object used to simulate
    first differences, and other model-specific quantities of
    interest, such as risk-ratios.}
  \item{call}{the options selected for \code{\link{sim}}, used to
    replicate quantities of interest. } 
\item{zelig.call}{the original command and options for
    \code{\link{zelig}}, used to replicate analyses. }
  \item{num}{the number of simulations requested. }
  \item{par}{the parameters (coefficients, and additional
    model-specific parameters).  You may wish to use the same set of
    simulated parameters to calculate quantities of interest rather
    than simulating another set.}
  \item{qi\$ev}{simulations of the expected values given the
    model and \code{x}. }
  \item{qi\$pr}{simulations of the predicted values given by the
    fitted values. }
  \item{qi\$fd}{simulations of the first differences (or risk
    difference for binary models) for the given \code{x} and \code{x1}.
    The difference is calculated by subtracting the expected values
    given \code{x} from the expected values given \code{x1}.  (If do not
    specify \code{x1}, you will not get first differences or risk
    ratios.) }
  \item{qi\$rr}{simulations of the risk ratios for binary and
    multinomial models.  See specific models for details.}
  \item{qi\$ate.ev}{simulations of the average expected
    treatment effect for the treatment group, using conditional
    prediction. Let \eqn{t_i} be a binary explanatory variable defining
    the treatment (\eqn{t_i=1}) and control (\eqn{t_i=0}) groups.  Then the
    average expected treatment effect for the treatment group is
    \deqn{ \frac{1}{n}\sum_{i=1}^n [ \, Y_i(t_i=1) -
      E[Y_i(t_i=0)] \mid t_i=1 \,],} 
    where \eqn{Y_i(t_i=1)} is the value of the dependent variable for
    observation \eqn{i} in the treatment group.  Variation in the
    simulations are due to uncertainty in simulating \eqn{E[Y_i(t_i=0)]},
    the counterfactual expected value of \eqn{Y_i} for observations in the
    treatment group, under the assumption that everything stays the
    same except that the treatment indicator is switched to \eqn{t_i=0}. }
  \item{qi\$ate.pr}{simulations of the average predicted
    treatment effect for the treatment group, using conditional
    prediction. Let \eqn{t_i} be a binary explanatory variable defining
    the treatment (\eqn{t_i=1}) and control (\eqn{t_i=0}) groups.  Then the
    average predicted treatment effect for the treatment group is
    \deqn{ \frac{1}{n}\sum_{i=1}^n [ \, Y_i(t_i=1) -
      \widehat{Y_i(t_i=0)} \mid t_i=1 \,],} 
    where \eqn{Y_i(t_i=1)} is the value of the dependent variable for
    observation \eqn{i} in the treatment group.  Variation in the
    simulations are due to uncertainty in simulating
    \eqn{\widehat{Y_i(t_i=0)}}, the counterfactual predicted value of
    \eqn{Y_i} for observations in the treatment group, under the
    assumption that everything stays the same except that the
    treatment indicator is switched to \eqn{t_i=0}. }
}

In the case of censored $Y$ in the exponential, Weibull, and lognormal
models, \code{sim} first imputes the uncensored values for $Y$ before
calculating the ATE.  

You may use the \code{\$} operator to extract any of the
above from \code{s.out}.  For example, \code{s.out\$qi\$ev} extracts the
simulated expected values.
}

\seealso{The full Zelig at \url{http://gking.harvard.edu/zelig}, and \code{boot}.  }

\author{
  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Olivia Lau <\email{olau@fas.harvard.edu}>
}

\keyword{file}











\eof
\name{summary.zelig}

\alias{summary.zelig}
\alias{summary}

\title{Summary of Simulated Quantities of Interest}

\description{Summarizes the object of class \code{\link{zelig}} (output
  from \code{\link{sim}}) which contains simulated quantities of
  interst.} 

\usage{
\method{summary}{zelig}(object, subset = NULL, CI = 95, stats = c("mean", "sd", "min", "max"), \dots)
}

\arguments{
  \item{object}{output object from \code{\link{sim}} (of class
    \code{"zelig"}).}
  \item{subset}{takes one of three values:
    \item{NULL}{(default) for more than one observation, summarizes all the
      observations at once for each quantity of interest.}
    \item{a numeric vector}{indicates which observations to summarize,
      and summarizes each one independently.}
    \item{all}{summarizes all the observations independently.}
    }
  \item{stats}{summary statistics to be calculated.}
  \item{CI}{a confidence interval to be calculated.}
  \item{\ldots}{further arguments passed to or from other methods.}
}

\value{
  \item{sim}{number of simulations, i.e., posterior draws.}
  \item{x}{values of explanatory variables used for simulation.}
  \item{x1}{values of explanatory variables used for simulation of first
    differences etc.}
  \item{qi.stats}{summary of quantities of interst.  Use
    \code{\link{names}} to view the model-specific items available in
    \code{qi.stats}.}
}

\seealso{
  \code{\link{zelig}}, \code{\link{setx}}, \code{\link{sim}},
  and \code{\link{names}}, and the full Zelig manual at
  \url{http://gking.harvard.edu/zelig}.  }

\author{
  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Olivia Lau <\email{olau@fas.harvard.edu}>
}

\keyword{file}






\eof
\name{ternarypoints}

\alias{ternarypoints}

\title{Adding Points to Ternary Diagrams}

\description{
Use \code{ternarypoints} to add points to a ternary diagram generated
using the \code{ternaryplot} function in the vcd library.  Use
ternary diagrams to plot expected values for multinomial choice models
with three categories in the dependent variable.  
}

\usage{
ternarypoints(object, pch = 19, col = "blue", ...)
}

\arguments{
\item{object}{The input object must be a matrix with three
  columns. }
\item{pch}{The selected type of point.  By default, \code{pch =
    19}, solid disks. } 
\item{col}{The color of the points.  By default, \code{col =
    "blue"}. }  
\item{\dots}{Additional parameters passed to \code{points}. }  
}

\value{
The \code{ternarypoints} command adds points to a previously existing
ternary diagram.  Use \code{ternaryplot} in the \code{vcd} library to
generate the main ternary diagram.  
}

\example{

}

\seealso{ The full Zelig manual at
  \url{http://gking.harvard.edu/zelig}, \code{points}, and
  \code{ternaryplot} in the \code{vcd} library.  }

\author{
  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Olivia Lau <\email{olau@fas.harvard.edu}>
}

\keyword{aplot}






\eof
\name{turnout}

\alias{turnout}

\title{Turnout Data Set from the National Election Survey}

\description{
  This data set contains individual-level turnout data. It pools several
  American National Election Surveys conducted during the 1992 presidential
  election year.  Only the first 2,000 observations (from a total of 15,837 
  observations) are included in the sample data.  
}

\usage{data(turnout)}

\format{A table containing 5 variables ("race", "age", "educate", 
"income", and "vote") and 2,000 observations.}

\source{National Election Survey}

\references{
  King, Gary, Michael Tomz, Jason Wittenberg (2000).
  ``Making the Most of Statistical Analyses: Improving Interpretation and 
  Presentation,'' \emph{American Journal of Political Science}, vol. 44,
  pp.341--355.
}

\keyword{datasets}

\eof
\name{zelig}

\alias{zelig}

\title{Estimating a Statistical Model}

\description{
The \code{zelig} command estimates a variety of statistical models.  Use
\code{zelig} output with \code{setx} and \code{sim} to compute
quantities of interest, such as predicted probabilities, expected
values, and first differences, along with the associated measures of
uncertainty (standard errors and confidence intervals).
}

\usage {
z.out <- zelig(formula, model, data, by, \dots)
}

\arguments{
\item{formula}{a symbolic representation of the model to be
  estimated, in the form \code{y \~\, x1 + x2}, where \code{y} is the
  dependent variable and \code{x1} and \code{x2} are the explanatory
  variables, and \code{y}, \code{x1}, and \code{x2} are contained in the
  same dataset.  (You may include more than two explanatory variables,
  of course.)  The \code{+} symbol means ``inclusion'' not
  ``addition.''  You may also include interaction terms and main
  effects in the form \code{x1*x2} without computing them in prior
  steps; \code{I(x1*x2)} to include only the interaction term and
  exclude the main effects; and quadratic terms in the form
  \code{I(x1^2)}.  }
\item{model}{the name of a statistical model, enclosed in \code{""}.
  Type \code{help.zelig("models")} to see a list of currently supported
  models.  }
\item{data}{the name of a data frame containing the variables
  referenced in the formula, or a list of multiply imputed data frames
  each having the same variable names and row numbers. }
\item{by}{a factor variable contained in \code{data}.  Zelig will subset
the data frame based on the levels in the \code{by} variable, and
estimate a model for each subset.  This a particularly powerful option
which will allow you to save a considerable amount of effort.  For
example, to run the same model on all fifty states, you could type:
\code{z.out <- zelig(y ~ x1 + x2, data = mydata, model = "ls", by = "state")}
  You may also use \code{by} to run models using MatchIt subclass.  }
\item{\dots}{additional arguments passed to \code{zelig},
  depending on the model to be estimated. }
}

\value{
Depending on the class of model selected, \code{zelig} will return
an object with elements including \code{coefficients}, \code{residuals},
and \code{formula} which may be summarized using
\code{summary(z.out)} or individually extracted using, for example,
\code{z.out\$coefficients}.  See the specific models listed above
for additional output values, or simply type \code{names(z.out)}.  
}

\seealso{ The full Zelig manual is available at
  \url{http://gking.harvard.edu/zelig}.
}

\author{
  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Olivia Lau <\email{olau@fas.harvard.edu}>
}

\keyword{file}

























\eof
